
## SecureKey REST API Schema Definitions ##
Schemas and Pydantic Models for the SecureKey VPN REST API.

SecureKey VPN is available on the Azure Marketplace.

Github: https://github.com/JETtech-Labs/sk_schemas

website: https://www.jettechlabs.com/



